@@ -60,7 +60,6 @@ isWin32 <- (.Platform$OS.type == "windows" && .Platform$r_arch == "i386")
 asIEC <- future:::asIEC
 ClusterRegistry <- future:::ClusterRegistry
 constant <- future:::constant
-detectCores <- future:::detectCores
 FutureRegistry <- future:::FutureRegistry
 gassign <- future:::gassign
 get_future <- future:::get_future
@@ -107,3 +106,27 @@ supportedStrategies <- function(cores = 1L, excl = c("multiprocess", "cluster"),
 }
 
 availCores <- min(2L, future::availableCores())
+
+
+## WORKAROUND: capture.output() gained argument 'split' in R 3.3.0
+if (getRversion() >= "3.3.0") {
+  capture.output <- utils::capture.output 
+} else {
+  capture.output <- function(..., split = FALSE) utils::capture.output(...)
+}
+
+recordConditions <- function(expr, ..., parse = TRUE) {
+  conditions <- list()
+  withCallingHandlers(expr, condition = function(c) {
+    attr(c, "received") <- Sys.time()
+    conditions[[length(conditions) + 1L]] <<- c
+  })
+  conditions
+}
+
+recordRelay <- function(...) {
+  stdout <- capture.output(conditions <- recordConditions(...), split = TRUE)
+  if (length(stdout) > 0) stdout <- paste0(stdout, "\n")
+  msgs <- sapply(conditions, FUN = conditionMessage)
+  list(stdout = stdout, msgs = msgs)
+}
